@@ -26,31 +26,31 @@
 #' @export
 #' @examples
 #' data(iris.clusterings)
-#' # R_CARGO \dontrun{
-#' # R_CARGO # Example disabled since Cargo was not found when installing from source package.
-#' # R_CARGO # You can still run the example if you install Cargo. Hint: cargo::install().
 #' dlso(iris.clusterings, loss=VI())
 #' dlso(iris.clusterings, loss=binder())
 #'
 #' # Compute expected loss using all draws, but pick the best among the first 10.
 #' dlso(iris.clusterings, loss=VI(), estimate=iris.clusterings[1:10,])
-#' # R_CARGO }
 #'
-dlso <- function(truth, loss=VI(), estimate=NULL) {
-  if ( is.null(estimate) ) estimate <- truth
+dlso <- function(truth, loss = VI(), estimate = NULL) {
+  if (is.null(estimate)) {
+    estimate <- truth
+  }
   expectedLoss <- partition.loss(truth, estimate, loss)
   index <- which.min(expectedLoss)
-  estimate <- truth[index,]
-  attr(estimate,"info") <- {
-    if ( inherits(loss, "salso.loss") ) {
-      if ( loss$loss == "binder" ) a <- loss$a
+  estimate <- truth[index, ]
+  attr(estimate, "info") <- {
+    if (inherits(loss, "salso.loss")) {
+      if (loss$loss == "binder") {
+        a <- loss$a
+      }
       loss <- loss$loss
     }
-    attr <- list(loss=loss, expectedLoss=expectedLoss[index])
-    as.data.frame(attr, row.names="")
+    attr <- list(loss = loss, expectedLoss = expectedLoss[index])
+    as.data.frame(attr, row.names = "")
   }
-  attr(estimate,"draws") <- truth
-  attr(estimate,"psm") <- NULL
+  attr(estimate, "draws") <- truth
+  attr(estimate, "psm") <- NULL
   class(estimate) <- "salso.estimate"
   estimate
 }
