@@ -38,67 +38,91 @@
 #' plot(summ, type="pairs", data=iris)
 #' plot(summ, type="dendrogram")
 #'
-summary.salso.estimate <- function(object, alternative, orderingMethod=1, ...) {
-  estimate <- as.vector(if ( ! missing(alternative) ) alternative else object)
-  if ( missing(alternative) ) estimate <- object
-  else {
+summary.salso.estimate <- function(
+  object,
+  alternative,
+  orderingMethod = 1,
+  ...
+) {
+  estimate <- as.vector(if (!missing(alternative)) alternative else object)
+  if (missing(alternative)) {
+    estimate <- object
+  } else {
     estimate <- as.integer(alternative)
     uniq <- unique(estimate)
-    if ( ! isTRUE(identical(uniq,seq_len(length(uniq)))) ) stop("The alternative clustering is not in canonical form.")
+    if (!isTRUE(identical(uniq, seq_len(length(uniq))))) {
+      stop("The alternative clustering is not in canonical form.")
+    }
+  }
+  loss <- attr(object, "info")$loss
+  x <- if (!is.null(attr(object, "psm"))) {
+    attr(object, "psm")
+  } else {
+    attr(object, "draws")
   }
-  loss <- attr(object,"info")$loss
-  x <- if ( ! is.null(attr(object,"psm")) ) attr(object,"psm") else attr(object,"draws")
   isPSM <- isPSM(x)
   nItems <- length(estimate)
   one2n <- seq_len(nItems)
   # pairwise similarity matrix
-  psm <- if ( isPSM ) x else psm(x)
+  psm <- if (isPSM) x else psm(x)
   # score
   score <- sapply(one2n, function(i) {
-    subset <- ( estimate == estimate[i] ) & ( one2n != i )
-    xi <- if ( isPSM ) x[subset, subset, drop=FALSE] else x[, subset, drop=FALSE]
-    partition.loss(xi, rep(1,ncol(xi)), loss)
+    subset <- (estimate == estimate[i]) & (one2n != i)
+    xi <- if (isPSM) {
+      x[subset, subset, drop = FALSE]
+    } else {
+      x[, subset, drop = FALSE]
+    }
+    partition.loss(xi, rep(1, ncol(xi)), loss)
   })
   score[is.na(score)] <- 0
   # meanPS
   meanPS <- sapply(seq_along(estimate), function(i) {
-    mean(psm[estimate==estimate[i], i])
+    mean(psm[estimate == estimate[i], i])
   })
   # exemplar
-  all <- data.frame(id=seq_len(nItems), label=as.vector(estimate), score=score)
+  all <- data.frame(
+    id = seq_len(nItems),
+    label = as.vector(estimate),
+    score = score
+  )
   exemplar <- sapply(split(all, all$label), function(d) {
-    if ( nrow(d) > 1 ) d$id[which.max(d$score)] else d$id
+    if (nrow(d) > 1) d$id[which.max(d$score)] else d$id
   })
   # dendrogram
   dendrogram <- partition.loss.dendrogram(as.vector(estimate), x, loss)
   # order
-  walk <- function(dendrogram, order=numeric()) {
-    if ( is.null(attr(dendrogram,"leaf")) ) {
-      order <- c(order,walk(dendrogram[[1]]))
-      order <- c(order,walk(dendrogram[[2]]))
+  walk <- function(dendrogram, order = numeric()) {
+    if (is.null(attr(dendrogram, "leaf"))) {
+      order <- c(order, walk(dendrogram[[1]]))
+      order <- c(order, walk(dendrogram[[2]]))
     } else {
-      order <- c(order,as.numeric(attr(dendrogram,"label")))
+      order <- c(order, as.numeric(attr(dendrogram, "label")))
     }
     order
   }
-  order <- if ( orderingMethod == 1 ) {
-    order(order(walk(dendrogram))[estimate], -1*score)
-  } else if ( orderingMethod == 2 ) {
-    order(estimate, order(hclust(as.dist(1-psm))$order))
-  } else stop("Unsupported value for the 'orderingMethod' argument.")
+  order <- if (orderingMethod == 1) {
+    order(order(walk(dendrogram))[estimate], -1 * score)
+  } else if (orderingMethod == 2) {
+    order(estimate, order(hclust(as.dist(1 - psm))$order))
+  } else {
+    stop("Unsupported value for the 'orderingMethod' argument.")
+  }
   # nClusters
   nClusters <- length(exemplar)
   # pairwise similarity matrix averaged by clustering estimate
-  m <- matrix(0.0, nrow=nClusters, ncol=nClusters)
-  for ( i in seq_len(nClusters) ) {
-    for ( j in seq_len(i) ) {
-      m[i,j] <- if ( i == j ) local({
-        y <- estimate == i
-        x <- psm[y, y, drop=FALSE]
-        diag(x) <- 0
-        sum(x) / ( length(x) - sum(y) )
-      }) else {
-        mean(psm[estimate==i, estimate==j])
+  m <- matrix(0.0, nrow = nClusters, ncol = nClusters)
+  for (i in seq_len(nClusters)) {
+    for (j in seq_len(i)) {
+      m[i, j] <- if (i == j) {
+        local({
+          y <- estimate == i
+          x <- psm[y, y, drop = FALSE]
+          diag(x) <- 0
+          sum(x) / (length(x) - sum(y))
+        })
+      } else {
+        mean(psm[estimate == i, estimate == j])
       }
     }
   }
@@ -110,7 +134,18 @@ summary.salso.estimate <- function(object, alternative, orderingMethod=1, ...) {
   sizes <- as.vector(sizes)
   names(sizes) <- names
   # finalize
-  result <- list(estimate=estimate, nClusters=nClusters, score=score, order=order, dendrogram=dendrogram, psm=psm, meanPS=meanPS, meanPSM=m, exemplar=exemplar, sizes=sizes)
+  result <- list(
+    estimate = estimate,
+    nClusters = nClusters,
+    score = score,
+    order = order,
+    dendrogram = dendrogram,
+    psm = psm,
+    meanPS = meanPS,
+    meanPSM = m,
+    exemplar = exemplar,
+    sizes = sizes
+  )
   class(result) <- "salso.summary"
   result
 }
